KeyAction enum

Actions that can be performed by special keys on the keyboard.

Inheritance
Available extensions

Values

backSpace → const KeyAction

Delete the character before the cursor.

enter → const KeyAction

Insert a newline character.

shift → const KeyAction

Toggle shift mode for uppercase letters.

space → const KeyAction

Insert a space character.

symbols → const KeyAction

Switch between letter and symbol layouts.

symbolsAlt → const KeyAction

Switch between primary and alternate symbol layouts.

emoji → const KeyAction

Switch between the active keyboard page and the emoji keyboard.

switchLanguage → const KeyAction

Switch keyboard language (reserved for future use).

done → const KeyAction

Done action (submit/close keyboard for single-line inputs).

go → const KeyAction

Go action (for URL inputs - navigate).

Search action (for search inputs).

send → const KeyAction

Send action (for chat/messaging inputs).

next → const KeyAction

Next action (move to next field).

previous → const KeyAction

Previous action (move to previous field).

call → const KeyAction

Call action (for phone inputs).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KeyAction>
A constant List of the values in this enum, in order of their declaration.