setEditingState method
Informs the text input control about editing state changes.
This method is called when the editing state of the attached input client has changed.
Implementation
@override
void setEditingState(TextEditingValue value) {
_currentValue = value;
}